@@ -154,7 +154,7 @@ int pkg_hash_fetch_unsatisfied_dependencies(ipkg_conf_t *conf, pkg_t * pkg,
 					    pkg_vec_insert(unsatisfied, pkg_scout);
 					}
 				   } else  {
-					ipkg_message(conf, IPKG_DEBUG, "not installing %s due to broken depends %s\n", pkg_scout->name, newstuff);
+					ipkg_message(conf, IPKG_DEBUG, "not installing %s due to broken depends \n", pkg_scout->name);
 					free (newstuff);
 				   }
 			      }
